# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-07 23:25
# @Author : 毛鹏
import unittest

from tests.cache_test import TestCache as b
# 确保这些导入路径是正确的
from tests.test_ass_excel import TestExcelTaskSheet
from tests.test_ass_sql import TestAssSql
from tests.test_ass_txt import TestTxtAssertion
from tests.test_cache import TestCache as a
from tests.test_git import TestGitOperations
from tests.test_mango import TestMango
from tests.test_mangos import TestMangos
from tests.test_random import TestRandom
from tests.test_sql_cache import TestSqlCache
from tests.test_flow import TestFlow
from tests.test_json import TestJson

def create_suite():
    suite = unittest.TestSuite()
    loader = unittest.TestLoader()

    # 添加所有测试类
    suite.addTest(loader.loadTestsFromTestCase(TestExcelTaskSheet))
    suite.addTest(loader.loadTestsFromTestCase(TestAssSql))
    suite.addTest(loader.loadTestsFromTestCase(TestTxtAssertion))
    suite.addTest(loader.loadTestsFromTestCase(a))
    suite.addTest(loader.loadTestsFromTestCase(b))
    suite.addTest(loader.loadTestsFromTestCase(TestMango))
    suite.addTest(loader.loadTestsFromTestCase(TestMangos))
    suite.addTest(loader.loadTestsFromTestCase(TestRandom))
    suite.addTest(loader.loadTestsFromTestCase(TestSqlCache))
    suite.addTest(loader.loadTestsFromTestCase(TestGitOperations))
    suite.addTest(loader.loadTestsFromTestCase(TestFlow))
    suite.addTest(loader.loadTestsFromTestCase(TestJson))

    return suite


if __name__ == '__main__':
    runner = unittest.TextTestRunner()
    runner.run(create_suite())



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-09-26 18:13
# @Author : 毛鹏
import unittest

from mangotools.mangos import build_decision_tree


class TestFlow(unittest.TestCase):
    def setUp(self):
        """在每个测试方法前初始化"""
        with open('test-flow.json', 'r', encoding='utf-8') as f:
            import json
            self.data = json.load(f)

    def test_flow(self):
        """测试基本缓存操作"""
        # 测试设置和获取缓存
        data = build_decision_tree(self.data)
        assert data is not None



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023/4/6 13:36
# @Author : 毛鹏

from .custom import CustomAssertion
from .file import FileAssertion, ExcelAssertion
from .sql import SqlAssertion
from .text import TextAssertion
from ..data_processor import DataProcessor
from ..database import MysqlConnect


class MangoAssertion(CustomAssertion, FileAssertion, SqlAssertion, TextAssertion):

    def __init__(self, mysql_conn: MysqlConnect | None = None, test_data: DataProcessor | None = None):
        SqlAssertion.__init__(self, mysql_conn)
        CustomAssertion.__init__(self, test_data)

    def ass(self, method: str, actual, expect=None) -> str:
        from mangotools.mangos import ass
        return ass(self, method, actual, expect,
                   text=TextAssertion, excel=ExcelAssertion, sql=SqlAssertion, custom=CustomAssertion)


__all__ = [
    'MangoAssertion',
    'TextAssertion',
    'FileAssertion',
    'SqlAssertion',
    'CustomAssertion',
    'ExcelAssertion',
]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: txt文件断言
# @Time   : 2025-07-04
# @Author : 毛鹏

import requests
import tempfile
import os

from mangotools.decorator import sync_method_callback
from mangotools.models import MethodModel


def read_txt_file(file_path):
    """
    统一处理TXT文件读取逻辑，支持本地路径和URL下载
    
    Args:
        file_path (str): TXT文件路径或URL
        
    Returns:
        str: 文件内容
    """
    # 判断是否为URL
    is_url = file_path.startswith(('http://', 'https://'))
    
    if is_url:
        # 下载文件内容
        response = requests.get(file_path)
        response.raise_for_status()
        return response.text
    else:
        # 直接读取本地文件
        with open(file_path, encoding='utf-8') as f:
            return f.read()


class TxtAssertion:
    """txt文件"""

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 0, [
        MethodModel(n='实际值', f='actual', p='实际内容或文件路径', d=True),
        MethodModel(n='预期值', f='expect', p='期望内容', d=True),
    ])
    def assert_txt_equal(actual: str, expect: str):
        """内容完全相等"""
        if actual.endswith('.txt') or actual.startswith(('http://', 'https://')):
            actual_content = read_txt_file(actual)
        else:
            actual_content = actual
        assert actual_content == expect, f'实际内容={actual_content}, 期望内容={expect}'
        return f'实际内容={actual_content}, 期望内容={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 1, [
        MethodModel(n='实际值', f='actual', p='实际内容或文件路径', d=True),
        MethodModel(n='预期值', f='expect', p='期望包含内容', d=True),
    ])
    def assert_txt_contains(actual: str, expect: str):
        """内容包含指定字符串"""
        if actual.endswith('.txt') or actual.startswith(('http://', 'https://')):
            actual_content = read_txt_file(actual)
        else:
            actual_content = actual
        assert expect in actual_content, f'实际内容={actual_content}, 期望包含={expect}'
        return f'实际内容={actual_content}, 期望包含={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 2, [
        MethodModel(n='实际值', f='actual', p='实际内容或文件路径', d=True),
        MethodModel(n='预期值', f='expect', p='期望长度', d=True),
    ])
    def assert_txt_length_equal(actual: str, expect: int):
        """内容长度等于期望值"""
        if actual.endswith('.txt') or actual.startswith(('http://', 'https://')):
            actual_content = read_txt_file(actual)
        else:
            actual_content = actual
        assert len(actual_content) == int(expect), f'实际长度={len(actual_content)}, 期望长度={expect}'
        return f'实际长度={len(actual_content)}, 期望长度={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 3, [
        MethodModel(n='实际值', f='actual', p='实际内容或文件路径', d=True),
        MethodModel(n='预期值', f='expect', p='期望开头内容', d=True),
    ])
    def assert_txt_startswith(actual: str, expect: str):
        """内容以指定字符串开头"""
        if actual.endswith('.txt') or actual.startswith(('http://', 'https://')):
            actual_content = read_txt_file(actual)
        else:
            actual_content = actual
        assert actual_content.startswith(expect), f'实际内容={actual_content}, 期望开头={expect}'
        return f'实际内容={actual_content}, 期望开头={expect}'

    @staticmethod
    @sync_method_callback('文件断言', 'txt断言', 4, [
        MethodModel(n='实际值', f='actual', p='实际内容或文件路径', d=True),
        MethodModel(n='预期值', f='expect', p='期望结尾内容', d=True),
    ])
    def assert_txt_endswith(actual: str, expect: str):
        """内容以指定字符串结尾"""
        if actual.endswith('.txt') or actual.startswith(('http://', 'https://')):
            actual_content = read_txt_file(actual)
        else:
            actual_content = actual
        assert actual_content.endswith(expect), f'实际内容={actual_content}, 期望结尾={expect}'
        return f'实际内容={actual_content}, 期望结尾={expect}'


# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2023-11-20 9:47
# @Author : 毛鹏
from deepdiff import DeepDiff

from mangotools.assertion.text import TextAssertion
from mangotools.database import MysqlConnect
from mangotools.decorator import sync_method_callback
from mangotools.models import MethodModel


def mysql_query(mysql_connect, actual, expect=None):
    result: list[dict] = mysql_connect.condition_execute(actual)
    assert result, f'实际={result}, 预期={expect}'
    first_row = result[0]
    return next(iter(first_row.values()))


class MysqlAssertion:
    """mysql"""

    def __init__(self, mysql_connect: MysqlConnect | None):
        self.mysql_connect: MysqlConnect = mysql_connect

    @sync_method_callback('sql断言', 'mysql', 1, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望条数', d=True),
    ])
    def assert_sql_count(self, actual: str, expect: int):
        """SQL查询结果条数"""
        result = self.mysql_connect.condition_execute(actual)
        assert len(result) == int(expect), f'实际条数={len(result)}, 预期条数={expect}'
        return f'实际条数={len(result)}, 预期条数={expect}'

    @sync_method_callback('sql断言', 'mysql', 2, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='请输入期望的dict', d=True),
    ])
    def assert_sql_first_row(self, actual: str, expect: dict):
        """数据相等"""
        result = self.mysql_connect.condition_execute(actual)
        assert result, f'实际={result}, 预期={expect}'
        first_row = result[0]
        diff = DeepDiff(first_row, expect, ignore_order=True)
        assert not diff, f'实际={actual}, 预期={expect}'
        return f'实际={actual}, 预期={expect}'

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_is_equal_to(self, actual: str, expect):
        """等于expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_is_equal_to(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_is_not_equal_to(self, actual: str, expect):
        """不等于expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_is_not_equal_to(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_is_length(self, actual: str, expect):
        """长度等于expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_is_length(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_sum_equal_expect(self, actual: str, expect):
        """长度等于expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_sum_equal_expect(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_contains(self, actual: str, expect):
        """包含expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_contains(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_is_equal_to_ignoring_case(self, actual: str, expect):
        """忽略大小写等于expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_is_equal_to_ignoring_case(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_contains_ignoring_case(self, actual: str, expect):
        """包含忽略大小写expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_contains_ignoring_case(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_contains_only(self, actual: str, expect):
        """仅包含expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_contains_only(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_does_not_contain(self, actual: str, expect):
        """不包含expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_does_not_contain(actual, expect)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_not_none(self, actual: str, expect=None):
        """不是null"""
        actual = mysql_query(self.mysql_connect, actual, '不是null')
        return TextAssertion.p_is_not_none(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_none(self, actual: str, expect=None):
        """是null"""
        actual = mysql_query(self.mysql_connect, actual, '是null')
        return TextAssertion.p_is_none(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_empty(self, actual: str, expect=None):
        """是空字符串"""
        actual = mysql_query(self.mysql_connect, actual, '是空字符串')
        return TextAssertion.p_is_empty(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_not_empty(self, actual: str, expect=None):
        """不是空符串"""
        actual = mysql_query(self.mysql_connect, actual, '不是空符串')
        return TextAssertion.p_is_not_empty(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_false(self, actual: str, expect=None):
        """是false"""
        actual = mysql_query(self.mysql_connect, actual, '是false')
        return TextAssertion.p_is_false(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_true(self, actual: str, expect=None):
        """是true"""
        actual = mysql_query(self.mysql_connect, actual, '是true')
        return TextAssertion.p_is_true(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_alpha(self, actual: str, expect=None):
        """是字母"""
        actual = mysql_query(self.mysql_connect, actual, '是字母')
        return TextAssertion.p_is_alpha(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
    ])
    def assert_sql_is_digit(self, actual: str, expect=None):
        """是数字"""
        actual = mysql_query(self.mysql_connect, actual, '是数字')
        return TextAssertion.p_is_digit(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_is_in(self, actual: str, expect: str):
        """在expect里面"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_is_in(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_is_not_in(self, actual: str, expect: str):
        """不在expect里面"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_is_not_in(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_starts_with(self, actual: str, expect: str):
        """以expect开头"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_starts_with(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_ends_with(self, actual: str, expect: str):
        """以expect结尾"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_ends_with(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_matches(self, actual: str, expect: str):
        """正则匹配等于expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_matches(actual)

    @sync_method_callback('sql断言', 'mysql', 3, [
        MethodModel(n='实际值', f='actual', p='请输入sql语句', d=True),
        MethodModel(n='预期值', f='expect', p='期望值', d=True),
    ])
    def assert_sql_does_not_match(self, actual: str, expect: str):
        """正则不匹配expect"""
        actual = mysql_query(self.mysql_connect, actual, expect)
        return TextAssertion.p_does_not_match(actual)



import os
import unittest

from mangotools.assertion import MangoAssertion
from mangotools.assertion.file import FileAssertion


class TestTxtAssertion(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.txt_file = 'test_sample.txt'
        cls.content = 'hello world\n这是一个测试文件。\nEND.'
        with open(cls.txt_file, 'w', encoding='utf-8') as f:
            f.write(cls.content)

    @classmethod
    def tearDownClass(cls):
        if os.path.exists(cls.txt_file):
            os.remove(cls.txt_file)

    def test_txt_equal(self):
        MangoAssertion().ass(FileAssertion.assert_txt_equal.__name__, 'hello world\n这是一个测试文件。\nEND.',
                             'hello world\n这是一个测试文件。\nEND.')
        MangoAssertion().ass(FileAssertion.assert_txt_equal.__name__, self.txt_file,
                             'hello world\n这是一个测试文件。\nEND.')

    def test_txt_contains(self):
        MangoAssertion().ass(FileAssertion.assert_txt_contains.__name__, 'hello world\n这是一个测试文件。\nEND.',
                             '测试文件')
        MangoAssertion().ass(FileAssertion.assert_txt_contains.__name__, self.txt_file, '测试文件')

    def test_txt_length_equal(self):
        MangoAssertion().ass(FileAssertion.assert_txt_length_equal.__name__, 'hello world', 11)
        MangoAssertion().ass(FileAssertion.assert_txt_length_equal.__name__, self.txt_file, len(self.content))

    def test_txt_startswith(self):
        MangoAssertion().ass(FileAssertion.assert_txt_startswith.__name__, 'hello world\nabc', 'hello')
        MangoAssertion().ass(FileAssertion.assert_txt_startswith.__name__, self.txt_file, 'hello world')

    def test_txt_endswith(self):
        MangoAssertion().ass(FileAssertion.assert_txt_endswith.__name__, 'abcEND.', 'END.')
        MangoAssertion().ass(FileAssertion.assert_txt_endswith.__name__, self.txt_file, 'END.')

    def test_txt_endswith1(self):
        from mangotools.data_processor import DataProcessor
        data = {
            'd': False,
        }
        MangoAssertion().p_is_false(DataProcessor.get_json_path_value(data, '$.d'))

    def test_txt_endswith2(self):
        MangoAssertion().p_is_not_none('None')

    def test_txt_endswith3(self):
        MangoAssertion().p_is_digit(1)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-24 10:01
# @Author : 毛鹏
import unittest

from mangotools.mangos import Mango, get, inside_post


class TestMangos(unittest.TestCase):

    def test_mango(self):
        Mango.v(1, '测试通过')
        print(type(get), get.__name__)
        print(type(inside_post), get.__name__)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-04 14:09
# @Author : 毛鹏
from ._excel import ExcelAssertion
from ._txt import TxtAssertion


class FileAssertion(ExcelAssertion, TxtAssertion):
    """文件断言"""



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2023-09-09 23:17
# @Author : 毛鹏

from ..models._models import *

__all__ = [
    'MysqlConingModel',
    'FunctionModel',
    'TestReportModel',
    'ResponseModel',
    'EmailNoticeModel',
    'WeChatNoticeModel',
    'ClassMethodModel',
    'MethodModel'
]



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-04 14:10
# @Author : 毛鹏
from assertpy import assert_that

from ...decorator import sync_method_callback
from ...models import MethodModel


def _assert_that(actual):
    if actual is None:
        raise AssertionError(f"实际值不能为 None ，可能是在获取实际值的时候就失败了！")
    return assert_that(actual)


class WhatIsItAssertion:
    """类型是什么"""

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 0, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_not_none(actual, expect=None):
        """不是null"""
        try:
            assert_that(actual).is_not_none()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不是None') from e
        return f'实际={actual}, 预期=不是None'

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 1, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_none(actual, expect=None):
        """是null"""
        try:
            assert_that(actual).is_none()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是None') from e
        return f'实际={actual}, 预期=是None'

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 2, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_empty(actual, expect=None):
        """是空字符串"""
        try:
            _assert_that(actual).is_empty()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是空字符串') from e
        return f'实际={actual}, 预期=是空字符串'

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 3, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_not_empty(actual, expect=None):
        """不是空符串"""
        try:
            _assert_that(actual).is_not_empty()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=不是空符串') from e
        return f'实际={actual}, 预期=不是空符串'

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 4, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_false(actual, expect=None):
        """是False"""
        try:
            assert_that(actual).is_false()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是False') from e
        return f'实际={actual}, 预期=是False'

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 5, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_true(actual, expect=None):
        """是True"""
        try:
            assert_that(actual).is_true()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是True') from e
        return f'实际={actual}, 预期=是True'

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 6, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_alpha(actual, expect=None):
        """是字母"""
        try:
            _assert_that(actual).is_alpha()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是字母') from e
        return f'实际={actual}, 预期=是字母'

    @staticmethod
    @sync_method_callback('内容断言', '类型是什么', 7, [
        MethodModel(n='实际值', f='actual', d=True)])
    def p_is_digit(actual, expect=None):
        """是整数"""
        try:
            _assert_that(str(actual)).is_digit()
        except AssertionError as e:
            raise AssertionError(f'实际={actual}, 预期=是数字') from e

        return f'实际={actual}, 预期=是数字'



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-08-08 17:13
# @Author : 毛鹏
import unittest

from mangotools.data_processor import DataProcessor

data = {"resExt": None, "resMsg": "请求成功!", "resCode": 200, "resData": {"list": [
    {"id": 196, "name": "Vb4Zd7u6Ma1", "type": 0, "userId": 77, "kolCount": 1, "userName": "自动化巡检员",
     "createTime": "2025-08-08 17:09:46", "requestStatus": 1, "lastUpdateTime": "2025-08-08 17:09:47",
     "requestStatusStats": {"fail": 0, "total": 1, "pending": 0, "running": 0, "success": 1, "requestId": ""}},
    {"id": 194, "name": "ZDfc0ROvKK1", "type": 0, "userId": 77, "kolCount": 1, "userName": "自动化巡检员",
     "createTime": "2025-08-08 17:06:52", "requestStatus": 1, "lastUpdateTime": "2025-08-08 17:06:53",
     "requestStatusStats": {"fail": 0, "total": 1, "pending": 0, "running": 0, "success": 1, "requestId": ""}},
    {"id": 193, "name": "OKN7ckRAFY1", "type": 0, "userId": 77, "kolCount": 1, "userName": "自动化巡检员",
     "createTime": "2025-08-08 16:55:55", "requestStatus": 1, "lastUpdateTime": "2025-08-08 16:55:56",
     "requestStatusStats": {"fail": 0, "total": 1, "pending": 0, "running": 0, "success": 1, "requestId": ""}},
    {"id": 192, "name": "213213", "type": 0, "userId": 77, "kolCount": None, "userName": "自动化巡检员",
     "createTime": "2025-08-08 16:48:31", "requestStatus": None, "lastUpdateTime": None, "requestStatusStats": None},
    {"id": 191, "name": "测试提报1", "type": 0, "userId": 77, "kolCount": 1, "userName": "自动化巡检员",
     "createTime": "2025-08-08 15:52:40", "requestStatus": 1, "lastUpdateTime": "2025-08-08 16:16:56",
     "requestStatusStats": {"fail": 0, "total": 1, "pending": 0, "running": 0, "success": 1, "requestId": ""}},
    {"id": 190, "name": "自动化提报22", "type": 0, "userId": 77, "kolCount": None, "userName": "自动化巡检员",
     "createTime": "2025-07-01 15:51:27", "requestStatus": None, "lastUpdateTime": None, "requestStatusStats": None}],
                                                                           "total": 6, "pageSize": 20, "pageIndex": 1},
        "resSuccess": True}


class TestJson(unittest.TestCase):

    def test_001(self):
        res = DataProcessor.get_json_path_value(data, '$.resData.list[*].name')
        print(res)
        assert res is not None
        from mangotools.assertion import MangoAssertion
        print(MangoAssertion.p_contains(res, 'Vb4Zd7u6Ma1'))

    def test_002(self):
        res = DataProcessor.get_json_path_value(data, '$.resData.list[*].name', 3)
        print(res)
        assert res is not None

    def test_003(self):
        res = DataProcessor.get_json_path_value(data, '$.resMsg')
        print(res)
        assert res is not None



import sqlite3
from typing import Union


class SQLiteConnect:

    def __init__(self, database_path: str):
        self.conn = None
        self.conn = sqlite3.connect(database_path)
        self.cursor = self.conn.cursor()

    def execute(self, sql: str, data: tuple | None = None) -> Union[list[dict], int]:
        if data:
            self.cursor.execute(sql, data)
        else:
            self.cursor.execute(sql)
        if sql.strip().split()[0].upper() == 'SELECT':
            rows = self.cursor.fetchall()
            column_names = [description[0] for description in self.cursor.description]
            result_list = [dict(zip(column_names, row)) for row in rows]
            return result_list
        elif sql.strip().split()[0].upper() in ['INSERT', 'UPDATE']:
            self.conn.commit()
            return self.cursor.rowcount
        elif sql.strip().split()[0].upper() == 'DELETE':
            self.conn.commit()
            return self.cursor.rowcount
        elif sql.strip().split()[0].upper() == 'CREATE':
            self.conn.commit()
            return self.cursor.rowcount
        else:
            self.conn.commit()
            return self.cursor.rowcount

    def close_connection(self) -> None:
        if self.conn:
            self.conn.close()

    def __del__(self):
        if self.conn:
            self.conn.close()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-04 11:13
# @Author : 毛鹏
import unittest

from mangotools.assertion import MangoAssertion
from mangotools.assertion.custom import v
from mangotools.data_processor import DataProcessor


class TestCustomAssertion(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        pass

    @classmethod
    def tearDownClass(cls):
        pass

    def test_txt_equal(self):
        self.test_data = DataProcessor()
        self.test_data.set_cache('账号A', 'maopeng@qq.com')
        MangoAssertion(test_data=self.test_data).ass(MangoAssertion.ass_func.__name__, v)
